Re-exports
pub use chunker::Chunk;pub use chunker::ChunkKind;pub use chunker::Chunker;pub use embed::CacheStats;pub use embed::EmbeddedChunk;pub use embed::EmbeddingService;pub use embed::ModelType;pub use error::CodeSearchError;pub use error::Result as CsResult;pub use file::FileInfo;pub use file::FileWalker;pub use file::Language;pub use file::WalkStats;pub use fts::FtsResult;pub use fts::FtsStore;pub use utils::group_chunks_by_path;pub use utils::group_chunks_by_path_with_capacity;pub use utils::group_embedded_chunks_by_path;pub use vectordb::SearchResult;pub use vectordb::StoreStats;pub use vectordb::VectorStore;
Modules
- bench
- cache
- chunker
- constants
- Central constants for codesearch configuration
- daemon
- Multi-repo daemon with periodic indexing.
- db_
discovery - Database discovery utilities for finding codesearch indexes
- embed
- error
- Centralized error types for codesearch
- file
- fts
- Full-text search module using Tantivy
- index
- logger
- Logging module for codesearch
- mcp
- MCP (Model Context Protocol) server for Claude Code integration
- output
- Output control for quiet mode and JSON output
- rerank
- Reranking and result fusion strategies
- search
- server
- utils
- Utility functions and helpers for codesearch
- vectordb
- watch
Macros
- info_
print - Print a message only if not in quiet mode
- warn_
print - Print to stderr only if not in quiet mode (for warnings)