check_database_integrity

Function check_database_integrity 

pub fn check_database_integrity(db_path: &Path) -> Option<String>
Check if a database directory exists but is incomplete/corrupt

Returns Some(reason) if the database is incomplete, None if valid or doesn’t exist