pub struct CachedBatchEmbedder {
pub batch_embedder: BatchEmbedder,
/* private fields */
}Expand description
Cached batch embedder that uses an embedding cache with memory limits
Fields
batch_embedder: BatchEmbedderImplementations
Sourceimpl CachedBatchEmbedder
impl CachedBatchEmbedder
Sourcepub fn new(batch_embedder: BatchEmbedder) -> Self
pub fn new(batch_embedder: BatchEmbedder) -> Self
Create a new cached batch embedder with default memory limit
Sourcepub fn with_memory_limit(
batch_embedder: BatchEmbedder,
max_memory_mb: usize,
) -> Self
pub fn with_memory_limit( batch_embedder: BatchEmbedder, max_memory_mb: usize, ) -> Self
Create with custom memory limit (in MB)
Sourcepub fn embed_chunks(&mut self, chunks: Vec<Chunk>) -> Result<Vec<EmbeddedChunk>>
pub fn embed_chunks(&mut self, chunks: Vec<Chunk>) -> Result<Vec<EmbeddedChunk>>
Embed chunks using cache when possible
Sourcepub fn embed_chunk(&mut self, chunk: Chunk) -> Result<EmbeddedChunk>
pub fn embed_chunk(&mut self, chunk: Chunk) -> Result<EmbeddedChunk>
Embed a single chunk with caching
Sourcepub fn cache_stats(&self) -> CacheStats
pub fn cache_stats(&self) -> CacheStats
Get cache statistics
Sourcepub fn clear_cache(&self)
pub fn clear_cache(&self)
Clear cache
Sourcepub fn dimensions(&self) -> usize
pub fn dimensions(&self) -> usize
Get embedding dimensions