pub struct FastEmbedder { /* private fields */ }Expand description
Fast embedding model using fastembed library
Implementations
Sourceimpl FastEmbedder
impl FastEmbedder
Sourcepub fn with_model(model_type: ModelType) -> Result<Self>
pub fn with_model(model_type: ModelType) -> Result<Self>
Create a new embedder with specified model
Sourcepub fn with_cache_dir(
model_type: ModelType,
cache_dir: Option<&Path>,
) -> Result<Self>
pub fn with_cache_dir( model_type: ModelType, cache_dir: Option<&Path>, ) -> Result<Self>
Create a new embedder with specified model and cache directory
Sourcepub fn embed_batch(&mut self, texts: Vec<String>) -> Result<Vec<Vec<f32>>>
pub fn embed_batch(&mut self, texts: Vec<String>) -> Result<Vec<Vec<f32>>>
Embed a batch of texts (processes in mini-batches to avoid OOM) Uses adaptive batch size based on model dimensions Can be overridden with CODESEARCH_BATCH_SIZE environment variable
Sourcepub fn embed_batch_chunked(
&mut self,
texts: Vec<String>,
batch_size: usize,
) -> Result<Vec<Vec<f32>>>
pub fn embed_batch_chunked( &mut self, texts: Vec<String>, batch_size: usize, ) -> Result<Vec<Vec<f32>>>
Embed a batch of texts with configurable mini-batch size
Sourcepub fn dimensions(&self) -> usize
pub fn dimensions(&self) -> usize
Get the dimensionality of embeddings
Sourcepub fn model_name(&self) -> &str
pub fn model_name(&self) -> &str
Get the model name
Sourcepub fn model_type(&self) -> ModelType
pub fn model_type(&self) -> ModelType
Get the model type