pub struct QueryCache { /* private fields */ }Expand description
Query embedding cache for fast repeated searches
Caches query embeddings to avoid re-embedding the same queries. Query reuse is very high in interactive sessions (e.g., “authentication”, “handle_file_modified”). Uses Moka LRU cache with automatic eviction.
Implementations
Sourceimpl QueryCache
impl QueryCache
Sourcepub fn with_memory_limit_mb(max_memory_mb: usize) -> Self
pub fn with_memory_limit_mb(max_memory_mb: usize) -> Self
Create a query cache with specified memory limit in MB
Sourcepub fn stats(&self) -> QueryCacheStats
pub fn stats(&self) -> QueryCacheStats
Get cache statistics
Sourcepub fn memory_usage_bytes(&self) -> usize
pub fn memory_usage_bytes(&self) -> usize
Get memory usage in bytes
Sourcepub fn memory_usage_mb(&self) -> f64
pub fn memory_usage_mb(&self) -> f64
Get memory usage in MB