Module extract

Module extract 

Regex-based code extraction for analysis modules

Provides lightweight extraction of functions, classes, and references from source code.

Functions

extract_classes
Extract class/struct definitions from content using language patterns
extract_function_calls
Extract function calls from a line of code
extract_functions
Extract function definitions from content using language patterns
extract_identifier_from_match
Extract identifier from regex captures (first capture group, or last word of full match)
extract_identifier_references
Extract all identifier references from content
is_keyword_or_builtin
Check if a name is a keyword or builtin function