SharedStores

Struct SharedStores 

pub struct SharedStores {
    pub vector_store: Arc<RwLock<VectorStore>>,
    pub fts_store: Arc<RwLock<FtsStore>>,
    pub readonly: bool,
    /* private fields */
}
Shared stores for concurrent access between MCP service and file watcher.

Uses RwLock to allow multiple concurrent readers (searches) with exclusive writer (indexing).

Fields

vector_store: Arc<RwLock<VectorStore>>fts_store: Arc<RwLock<FtsStore>>readonly: bool

Whether this instance is in readonly mode

Implementations

Source

impl SharedStores

pub fn new(db_path: &Path, dimensions: usize) -> Result<Self>

Create new shared stores from the database path (read-write mode).

This acquires a writer lock. If another process already has the lock, this will fail with an error.

pub fn new_readonly(db_path: &Path, dimensions: usize) -> Result<Self>

Create shared stores in readonly mode (for secondary instances).

This does not acquire any locks and cannot write to the database. File watching is not supported in readonly mode.

pub fn new_or_readonly( db_path: &Path, dimensions: usize, ) -> Result<(Self, bool)>

Try to create shared stores, falling back to readonly mode if locked.

Returns (SharedStores, is_readonly) tuple.