pub fn search_code(
query: &str,
path: &Path,
options: &SearchOptions,
) -> Result<Vec<SearchResult>, Box<dyn Error>>Expand description
Main search function with support for fuzzy, regex, semantic, and cached searches
pub fn search_code(
query: &str,
path: &Path,
options: &SearchOptions,
) -> Result<Vec<SearchResult>, Box<dyn Error>>Main search function with support for fuzzy, regex, semantic, and cached searches