pub fn check_database_integrity(db_path: &Path) -> Option<String>
Check if a database directory exists but is incomplete/corrupt
Returns Some(reason) if the database is incomplete, None if valid or doesn’t exist
Some(reason)
None