Regex-based code extraction for analysis modules
Provides lightweight extraction of functions, classes, and references from source code.
Functions
- extract_
classes - Extract class/struct definitions from content using language patterns
- extract_
function_ calls - Extract function calls from a line of code
- extract_
functions - Extract function definitions from content using language patterns
- extract_
identifier_ from_ match - Extract identifier from regex captures (first capture group, or last word of full match)
- extract_
identifier_ references - Extract all identifier references from content
- is_
keyword_ or_ builtin - Check if a name is a keyword or builtin function